Skip to contents

These functions gather chroma or timbre data frames from Sonic Visualiser into a nested format for further processing.

Usage

compmus_wrangle_chroma(dat)

compmus_wrangle_timbre(dat)

Arguments

dat

Data frame from Sonic Visualiser based on a chroma- or cepstrogram layer.

Functions

  • compmus_wrangle_timbre(): Wrangle chroma/timbre vectors