Skip to contents

Given a key estimate, transpose chroma vectors back to C.

Usage

compmus_c_transpose(dat, key)

Arguments

dat

Data frame with a pitches column containing chroma vectors.

key

Character string naming the global or local tonal centre.