Pairwise distances in long format
compmus_long_distance.RdWe use a number of distance measures in Computational Musicology.
compmus_long_distance brings them together into one place, along with
common alternative names. In order to support plotting, the distances are
returned in long format rather than matrix format. It is designed for
convenience, not speed.
Usage
compmus_long_distance(xdat, ydat, feature, method = "euclidean")
compmus_self_similarity(dat, feature, method = "euclidean")Details
The following methods are supported.
manhattan,citybolock,taxicab,L1,totvarManhattan distance.
euclidean,L2Euclidean distance.
chebyshev,maximumChebyshev distance.
pearson,correlationPearson's pseudo-distance.
cosineCosine pseudo-distance.
angularAngular distance.
aitchisonAitchison distance.