Match chroma vectors against templates
compmus_match_pitch_template.RdCompares chroma vectors in a data frame against a list of templates, most likely key or chord profiles.
Arguments
- dat
A data frame containing chroma vectors in a
pitchescolumn.- templates
A data frame with a
namecolumn for each template and the templates themselves in atemplatecolumn.- method
A character string indicating which distance metric to use (see
compmus_long_distance). Default is cosine distance.- norm
An optional character string indicating the method for pre-normalising each vector with
compmus_normalise. Default is Euclidean.