Wrangle chroma/timbre vectors
compmus_wrangle_chroma.RdThese functions gather chroma or timbre data frames from Sonic Visualiser into a nested format for further processing.
compmus_wrangle_chroma.RdThese functions gather chroma or timbre data frames from Sonic Visualiser into a nested format for further processing.